#
# spec file for package python-ldappool
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ldappool
Version:        3.0.0
Release:        4.5
Summary:        A connection pool for python-ldap
License:        GPL-2.0-or-later OR MPL-1.1 OR LGPL-2.1-or-later
Group:          Development/Languages/Python
URL:            https://git.openstack.org/cgit/openstack/ldappool
Source:         https://files.pythonhosted.org/packages/source/l/ldappool/ldappool-%{version}.tar.gz
# PATCH-FIX-UPSTREAM remove-six-dep.patch https://review.opendev.org/c/openstack/ldappool/+/805495
Patch:          remove-six-dep.patch
BuildRequires:  %{python_module ldap >= 3.0.0}
BuildRequires:  %{python_module pbr}
# SECTION stestr is only available for primary python3 flavor (openstack package)
BuildRequires:  %{python_module stestr}
BuildRequires:  %{python_module testresources}
BuildRequires:  %{python_module testtools}
# /SECTION
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-ldap >= 3.0.0
Requires:       python-prettytable
BuildArch:      noarch
%python_subpackages

%description
A simple connector pool for python-ldap.

The pool keeps LDAP connectors alive and let you reuse them,
drastically reducing the time spent to initiate a ldap connection.

The pool has useful features like:

- transparent reconnection on failures or server restarts
- configurable pool size and connectors timeouts
- configurable max lifetime for connectors
- a context manager to simplify acquiring and releasing a connector

%prep
%autosetup -p1 -n ldappool-%{version}
sed -i 's/PrettyTable<0.8,>=0.7.2/prettytable>=0.7.2/' requirements.txt

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_expand rm -rf %{buildroot}%{$python_sitelib}/ldappool/tests

%check
%python_exec -m stestr.cli run

%files %{python_files}
%doc CHANGES.rst README.rst
%{python_sitelib}/ldappool
%{python_sitelib}/ldappool-%{version}*-info

%changelog
* Wed Jan 24 2024 Dirk Müller <dmueller@suse.com>
- switch to new python stack
- build for all python flavors
* Fri Nov 25 2022 Daniel Garcia <daniel.garcia@suse.com>
- Add remove-six-dep.patch upstream patch
  https://review.opendev.org/c/openstack/ldappool/+/805495
- Remove python_module macro definition
- More specific python_sitelib in %%files
- Remove tests from package
* Fri Nov 26 2021 Dirk Müller <dmueller@suse.com>
- fix requires on renamed prettytable
* Tue Oct 26 2021 Dirk Müller <dmueller@suse.com>
- update to 3.0.0:
  * Remove lower-constraints, uncap PrettyTable
  * Switch to newer openstackdocstheme and reno versions
  * Cleanup py27 support
  * Update hacking for Python3
  * [ussuri][goal] Drop python 2.7 support and testing
  * Follow the PTI for docs
  * Add Python 3 Train unit tests
  * Add bindep.txt
  * Sync Sphinx requirement
  * OpenDev Migration Patch
  * Update the min version of tox
  * Drop py35 jobs
* Mon Jan 25 2021 Benjamin Greiner <code@bnavigator.de>
- OpenStack package -- test on primary python3 only.
* Tue Nov 24 2020 John Vandenberg <jayvdb@gmail.com>
- Remove upper pin on PrettyTable dependency
* Thu Mar 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.4.1:
  * Various release notes and docu updates
* Mon Dec 10 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 2.4.0:
  * Allow pool status to be printed as a table
  * Add plumbing to support reno release notes
  * Handle retry logic for timeouts with multiple LDAP servers
  * Improve connection retry logging
  * PY3: switch to using unicode text values
  * Don't quote {posargs} in tox.ini
  * Removed older version of python added 3.5
  * add python 3.6 unit test job
  * import zuul job settings from project-config
  * fix tox python3 overrides
  * fix ldappool bad password retry logic
  * Add author email to setup.cfg
  * Switch to python-ldap again
  * Bump to hacking 1.1.x
  * Switch to stestr
  * add lower-constraints job
  * Updated from global requirements
  * Avoid tox\_install.sh for constraints support
  * Turn on warning-is-error for sphinx build
  * Switch from oslosphinx to openstackdocstheme
  * Fix html\_last\_updated\_fmt for Python3
- Update URL
* Thu Aug 24 2017 tbechtold@suse.com
- update to 2.1.0
  * Updated from global requirements
  * Don't call start\_tls\_s() twice
  * [Fix gate]Update test requirement
  * Add Constraints support
  * update README to reflect actual ldap dependency
  * Expose SERVER\_DOWN if connection fails
- convert to singlespec
* Wed May 18 2016 dmueller@suse.com
- update to 2.0.0:
  * Add py3 info to setup.cfg
  * Updated from global requirements
  * make ldappool py3 compatible
  * use standard docstring convention for parameters
  * Use standard-library logging to record errors
  * Raise an explicit BackendError on TLS failures
  * Fix pool_full race condition
  * additional files to ignore in .gitignore
  * Fix license in setup.py
  * add .gitreview and fix ldappool gate
  * Add test-requirements for py27 testing
  * PEP8 fixes
  * Add support for tox unit testing
  * Initialize conn in _create_connector (fixes: #7)
  * Use setuptools when available
  * #4: UTF-8 encode passwd only when set
* Wed Feb  4 2015 dmueller@suse.com
- fix license
* Mon Jan 19 2015 rhafer@suse.com
- Initial package. Version 1.0
